@@ -4,7 +4,7 @@
 // C++ header file
 // This file is part of RGL
 //
-// $Id: Device.hpp 432 2006-03-05 15:45:47Z dmurdoch $
+// $Id: Device.hpp 511 2006-08-24 20:00:43Z dmurdoch $
 
 #include "Disposable.hpp"
 #include "types.h"
@@ -36,8 +36,8 @@ public: // -- all methods are blocking until action completed
   bool postscript(int format, const char* filename);
 
   bool clear(TypeID stackTypeID);
-  bool add(SceneNode* node);
-  bool pop(TypeID stackTypeID);
+  int add(SceneNode* node); // -- return a unique id if successful, or zero if not
+  bool pop(TypeID stackTypeID, int id);
 
   // accessor method for Scene, modeled after getBoundingBox()
   // from scene.h
